@@ -1,6 +1,6 @@
 use crate::atomic::{self, ArcBool};
 use async_trait::async_trait;
-use ockam_core::{Address, LocalMessage, Processor, Result, TransportMessage};
+use ockam_core::{Address, Decodable, LocalMessage, Processor, Result, TransportMessage};
 use ockam_node::Context;
 use ockam_transport_core::TransportError;
 use tokio::{io::AsyncReadExt, net::tcp::OwnedReadHalf};
@@ -69,8 +69,8 @@ impl Processor for TcpRecvProcessor {
             }
 
             // Deserialize the message now
-            let mut msg: TransportMessage = serde_bare::from_slice(buf.as_slice())
-                .map_err(|_| TransportError::RecvBadMessage)?;
+            let mut msg =
+                TransportMessage::decode(&buf).map_err(|_| TransportError::RecvBadMessage)?;
 
             // Insert the peer address into the return route so that
             // reply routing can be properly resolved
